==> serverless-logic-web-tools-swf-deployment-webapp2-0.0.16.tgz: package/src/__tests__/impl/WorkflowFormGatewayApiImpl.test.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { getCustomWorkflowSchema, startWorkflowRest } from "../../apis";
import { WorkflowFormGatewayApi, WorkflowFormGatewayApiImpl } from "../../impl/WorkflowFormGatewayApiImpl";

jest.mock("../../apis/apis", () => ({
  getCustomWorkflowSchema: jest.fn(),
  startWorkflowRest: jest.fn(),
}));

let gatewayApi: WorkflowFormGatewayApi;

describe("WorkflowFormListGatewayApi tests", () => {
  beforeEach(() => {
    jest.clearAllMocks();
    gatewayApi = new WorkflowFormGatewayApiImpl({} as any);
  });

  it("get custom workflow schema", async () => {
    const workflowName = "expression";
    await gatewayApi.getCustomWorkflowSchema(workflowName);
    expect(getCustomWorkflowSchema).toHaveBeenCalledWith({}, "expression");
  });

  it("start workflow rest", async () => {
    await gatewayApi.startWorkflow("http://localhost:8080/test", {
      name: "John",
    });
    expect(startWorkflowRest).toHaveBeenCalledWith({ name: "John" }, "http://localhost:8080/test", "");
  });
});

==> serverless-logic-web-tools-swf-deployment-webapp2-0.0.20.tgz: package/src/__tests__/impl/WorkflowFormGatewayApiImpl.test.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import {
  startWorkflowRest,
  getCustomWorkflowSchemaFromApi,
} from "@kie-tools/runtime-tools-gateway-api/dist/gatewayApi/apis";
import { WorkflowFormGatewayApi, WorkflowFormGatewayApiImpl } from "../../impl/WorkflowFormGatewayApiImpl";

jest.mock("@kie-tools/runtime-tools-gateway-api/dist/gatewayApi/apis", () => ({
  startWorkflowRest: jest.fn(),
  getCustomWorkflowSchemaFromApi: jest.fn(),
}));

let gatewayApi: WorkflowFormGatewayApi;

describe("WorkflowFormListGatewayApi tests", () => {
  beforeEach(() => {
    jest.clearAllMocks();
    gatewayApi = new WorkflowFormGatewayApiImpl({} as any);
  });

  it("get custom workflow schema", async () => {
    const workflowName = "expression";
    await gatewayApi.getCustomWorkflowSchema(workflowName);
    expect(getCustomWorkflowSchemaFromApi).toHaveBeenCalledWith({}, "expression");
  });

  it("start workflow rest", async () => {
    await gatewayApi.startWorkflow("http://localhost:8080/test", {
      name: "John",
    });
    expect(startWorkflowRest).toHaveBeenCalledWith({ name: "John" }, "http://localhost:8080/test", "");
  });
});
